.. Charm Helpers documentation master file, created by
   sphinx-quickstart on Fri Jun  6 10:34:44 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Charm Helpers Documentation
===========================

The ``charmhelpers`` Python library is an extensive collection of functions and classes
for simplifying the development of `Juju Charms`_. It includes utilities for:

* Interacting with the host environment
* Managing hook events
* Reading and writing charm configuration
* Installing dependencies
* Much, much more!

.. toctree::
   :maxdepth: 2

   getting-started
   example-index
   api/charmhelpers

.. toctree::
   :caption: Project
   :glob:
   :maxdepth: 3

   contributing
   changelog


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`


.. _Juju Charms: https://juju.ubuntu.com/docs/
